Learn R Programming

edgemodelr (version 0.2.0)

edge_resolve_model_name: Resolve a model name to the canonical entry in edge_list_models()

Description

Resolve a model name to the canonical entry in edge_list_models()

Usage

edge_resolve_model_name(model_name, models = NULL)

Value

Canonical model name or NA if not found

Arguments

model_name

User-provided model name

models

Optional models data.frame