powered by
Find and load an Ollama model using a partial SHA-256 hash instead of the full path. This is more convenient than typing out the full blob path.
edge_load_ollama_model(partial_hash, n_ctx = 2048L, n_gpu_layers = 0L)
Model context if successful, throws error if not found or incompatible
First few characters of the SHA-256 hash
Maximum context length (default: 2048)
Number of layers to offload to GPU (default: 0)
if (FALSE) { # Load model using first 8 characters of SHA hash # ctx <- edge_load_ollama_model("b112e727") # result <- edge_completion(ctx, "Hello", n_predict = 10) # edge_free_model(ctx) }
Run the code above in your browser using DataLab